############################################################################
# Matt Rodriguez, LBNL
#Copyright (c) 2003, The Regents of the University of California,
#through Lawrence Berkeley National Laboratory 
#(subject to receipt of any required approvals from the U.S. Dept. of Energy). 
#All rights reserved. 
###########################################################################

import ConfigParser, unittest
from pyGlobus.security import check_keyfile, check_certfile
from pyGlobus.security import get_user_cert_filename
from pyGlobus.security import get_host_cert_filename
from pyGlobus.security import GSIException
from pyGlobus.security import get_cert_dir
from pyGlobus.security import get_proxy_filename
from pyGlobus.security import get_service_cert_filename
from pyGlobus.security import grid_proxy_info
from pyGlobus.security import gridmap
from pyGlobus.security import userok
from pyGlobus.security import map_local_user
import os
import re

EXCEPTION_STRING_NO_HOST_CERT = "Could not find a valid certificate file: The host cert could not be found in"
EXCEPTION_STRING_NO_ROOT_PRIVELEGES = "Error with certificate filename"

class securityFunctionsTestCase(unittest.TestCase):
    """Unittests for the security modules functions
       3 of these tests require the user to have a ~/.gridmap file 
    """
    
    def tearDown(self):
        pass
        
    def checkGetHostCertFileName(self):
        try:
            files = get_host_cert_filename()
        except GSIException, ex:
            exceptString = str(ex)
            if exceptString.find(EXCEPTION_STRING_NO_HOST_CERT) > -1: 
                print "This machine does not have host cert and a host key"
                print "TEST PASSED"
            elif exceptString.find(EXCEPTION_STRING_NO_ROOT_PRIVELEGES) > -1:  
                print "You must be root to access the hostcert and hostkey"
                print "TEST PASSED"
            else:
                print 'got exception: ', exceptString
                raise ex
        
    def checkGetAndCertFile(self):
        certfile, keyfile = get_user_cert_filename()
        check_certfile(certfile)
        check_keyfile(keyfile)

    def checkGetCertDir(self):
        directory = get_cert_dir()
        print directory

    def checkGetProxyFileName(self):
        proxyFile =get_proxy_filename()
        print proxyFile

    def checkGridmap(self):
        DN, proxyDict = grid_proxy_info()
        l = DN.splitlines()
        subjectDN = l[1].split(': ')[1]
        print subjectDN
        user = gridmap(subjectDN)
        print user
        
    def checkUserok(self):
        DN,proxyDict = grid_proxy_info()
        l = DN.splitlines()
        subjectDN = l[1].split(': ')[1]
        user = gridmap(subjectDN)
        ok  = userok(subjectDN, user)
        if ok == 1:
            pass
        else:
            assert 0, "TEST FAILED"
            
    def checkMapLocalUser(self):
        user = os.getenv("LOGNAME")
        dn = map_local_user(user)

def makeTestSuite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(securityFunctionsTestCase, "check"))
    return suite


def main():
    unittest.main(defaultTest="makeTestSuite")


if __name__ == "__main__" : main()
